@@ -112,8 +112,6 @@ async def send(oracle_name, asset, starkex_signed_price, evm_signed_price, stork
     print(f"Sending message for asset {asset} to stork.")
 
     await stork_endpoint.send(json.dumps(message))
-    # recv() after send() in order to catch disconnect events
-    await stork_endpoint.recv()
 
 
 def median_price_update(close, prices, total, current_exchange, current_asset):
@@ -158,12 +156,13 @@ def median_price_update(close, prices, total, current_exchange, current_asset):
 
     # Remove data older than 10 seconds
     for exch in list(prices[current_asset]):
-        timestamp = prices[current_asset][exch]["timestamp"]
-        exch_price = prices[current_asset][exch]["price"]
-        if (int(time.time()) - timestamp) < 10:
-            total.append(exch_price)
-        else:
-            del prices[current_asset][exch]
+        if exch != "last_update":
+            timestamp = prices[current_asset][exch]["timestamp"]
+            exch_price = prices[current_asset][exch]["price"]
+            if (int(time.time()) - timestamp) < 10:
+                total.append(exch_price)
+            else:
+                del prices[current_asset][exch]
 
     # Calculate and return the median price
     if len(total) > 0:
